@@ -19,6 +19,10 @@ use crate::{CaseMatching, FuzzyAlgorithm, Selector};
 ///
 /// # ENVIRONMENT VARIABLES
 ///
+/// ## NO_COLOR
+///
+/// If set and not empty, sk will not use any colors in the output.
+///
 /// ## SKIM_DEFAULT_COMMAND
 ///
 /// Default command to use when input is tty. On *nix systems, sk runs the command with sh -c, so make  sure  that
@@ -88,6 +92,12 @@ pub struct SkimOptions {
     #[arg(long, help_heading = "Search")]
     pub tac: bool,
 
+    /// Minimum query length to start showing results
+    ///
+    /// Only show results when the query is at least this many characters long
+    #[arg(long, help_heading = "Search")]
+    pub min_query_length: Option<usize>,
+
     /// Do not sort the results
     ///
     /// *Often used in combination with `--tac`*
@@ -462,6 +472,7 @@ pub struct SkimOptions {
     /// - **light**: 256-color light theme
     /// - **16**: Basic 16-color theme
     /// - **bw**: Minimal black & white theme (no colors, just styles)
+    /// - **none**: Minimal black & white theme (no colors, no styles). Default when NO_COLOR is set
     /// - **molokai**: Molokai-inspired 256-color theme
     ///
     /// ### Color Customization
